<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/paquet-compagnon?lang_cible=fr_tu
// ** ne pas modifier le fichier **

return [

	// C
	'compagnon_description' => 'Le compagnon offre une aide aux utilisateurs
		lors de leur première visite dans l’espace privé de SPIP.',
	'compagnon_nom' => 'Compagnon',
	'compagnon_slogan' => 'Assistant de premiers pas avec SPIP',
];
